@@ -5,19 +5,19 @@ test_that("list extensions", {
 })
 
 test_that("strikethrough", {
-  md <- "foo ~bar~ baz"
-  expect_equal(markdown_html(md, extensions = FALSE), "<p>foo ~bar~ baz</p>\n")
-  expect_equal(markdown_html(md, extensions = TRUE), "<p>foo <del>bar</del> baz</p>\n")
+  md <- "~Hello~ ~~world~~!"
+  expect_equal(markdown_html(md), "<p>~Hello~ ~~world~~!</p>\n")
+  expect_equal(markdown_html(md, extensions = "strikethrough"), "<p>~Hello~ <del>world</del>!</p>\n")
 
-  expect_equal(markdown_latex(md, extensions = FALSE), "foo \\textasciitilde{}bar\\textasciitilde{} baz\n")
-  expect_equal(markdown_latex(md, extensions = TRUE), "foo \\sout{bar} baz\n")
+  expect_equal(markdown_latex(md), "\\textasciitilde{}Hello\\textasciitilde{} \\textasciitilde{}\\textasciitilde{}world\\textasciitilde{}\\textasciitilde{}!\n")
+  expect_equal(markdown_latex(md, extensions = "strikethrough"), "\\textasciitilde{}Hello\\textasciitilde{} \\sout{world}!\n")
 
-  expect_equal(markdown_man(md, extensions = FALSE), ".PP\nfoo ~bar~ baz\n")
-  expect_equal(markdown_man(md, extensions = TRUE), ".PP\nfoo \n.ST \"bar\"\n baz\n")
+  expect_equal(markdown_man(md), ".PP\n~Hello~ ~~world~~!\n")
+  expect_equal(markdown_man(md, extensions = "strikethrough"), ".PP\n~Hello~ \n.ST \"world\"\n!\n")
 
   library(xml2)
-  doc1 <- xml_ns_strip(read_xml(markdown_xml(md, extensions = FALSE)))
-  doc2 <- xml_ns_strip(read_xml(markdown_xml(md, extensions = TRUE)))
+  doc1 <- xml_ns_strip(read_xml(markdown_xml(md)))
+  doc2 <- xml_ns_strip(read_xml(markdown_xml(md, extensions = "strikethrough")))
   expect_length(xml_find_all(doc1, "//strikethrough"), 0)
   expect_length(xml_find_all(doc2, "//strikethrough"), 1)
 
